#
# spec file for package accel-config
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_libname libaccel-config1
%define src_name idxd-config-accel-config-v%{version}
Name:           accel-config
Version:        3.4.7
Release:        150500.1.2
Summary:        Configure accelerator subsystem devices
License:        GPL-2.0-only
URL:            https://github.com/intel/idxd-config
Source:         %{url}/archive/accel-config-v%{version}.tar.gz#/%{src_name}.tar.gz
BuildRequires:  asciidoc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  binutils
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xmlto
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(uuid)
Requires:       %{pkg_libname} = %{version}-%{release}
ExclusiveArch:  x86_64

%description
Utility library and command-line tool for configuring the Intel
Data Streaming Accelerator (DSA) and Intel Analytics Accelerator
(IAX).

%package -n %{name}-devel
Summary:        Development files for libaccfg
License:        LGPL-2.1-only
Requires:       %{pkg_libname} = %{version}-%{release}

%description -n %{name}-devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n %{pkg_libname}
Summary:        Configuration library for accelerator subsystem devices
License:        LGPL-2.1-only
Requires:       kmod(idxd.ko)

%description -n %{pkg_libname}
Libraries for %{name}.

%prep
%setup -q -n %{src_name}

%build
echo %{version} > version
./autogen.sh
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{pkg_libname} -p /sbin/ldconfig
%postun -n %{pkg_libname} -p /sbin/ldconfig

%files
%license Documentation/COPYING licenses/BSD-MIT licenses/CC0
%license licenses/accel-config-licenses LICENSE_GPL_2_0
%{_bindir}/accel-config
%{_mandir}/man1/accel-config*
%dir %{_sysconfdir}/accel-config
%config %{_sysconfdir}/accel-config/accel-config.conf.sample
%dir %{_datadir}/accel-config
%dir %{_datadir}/accel-config/contrib
%dir %{_datadir}/accel-config/contrib/configs
%{_datadir}/accel-config/contrib/configs/app_profile.conf
%{_datadir}/accel-config/contrib/configs/net_profile.conf
%{_datadir}/accel-config/contrib/configs/os_profile.conf
%{_datadir}/accel-config/contrib/configs/profilenote.txt
%{_datadir}/accel-config/contrib/configs/storage_profile.conf

%files -n %{pkg_libname}
%doc README.md
%license Documentation/COPYING licenses/BSD-MIT licenses/CC0
%license licenses/libaccel-config-licenses accfg/lib/LICENSE_LGPL_2_1
%{_libdir}/libaccel-config.so.*

%files -n %{name}-devel
%license Documentation/COPYING
%{_includedir}/accel-config/
%{_libdir}/libaccel-config.so
%{_libdir}/pkgconfig/libaccel-config.pc

%changelog
* Wed Sep 14 2022 danilo.spinella@suse.com
- Update to version 3.4.7:
  * No relevant changes
- Update to version 3.4.6.5:
  * Add Zcompress32, Zdecompress32, Compress and Decompress test
  * Add Zcompress16 and Zdecompress16 to IAA test
  * Add operation CRC64 into IAA test
  * Bug fixes
* Mon May 16 2022 danilo.spinella@suse.com
- Update to version 3.4.6.4:
  * Init IAA test and add No-op operation
  * Separate common codes from DSA source code file
  * Bug fixes
* Thu Apr 21 2022 rpm@fthiessen.de
- Update to version 3.4.6.3:
  * Allow use of config files with driver_name attr with older drivers
* Wed Mar 30 2022 danilo.spinella@suse.com
- Update to version 3.4.6.2:
  * Allow driver_name to be configured in guest
  * Disable mdev tests
  * Update driver_name in unit test configs
  * Improve error message in config attr failures
- Update to version 3.4.6.1:
  * Bug fix in wq driver name configuration
  * Test configs add driver name attr
- Update to version 3.4.6:
  * Support new "read_buffer" attributes that replace "token" attributes
  * Deprecate attributes with "token" names
  * Add support for driver_name attr to get wq driver name
  * Fix a read buffer length related bug
  * Add opcode operation support
- Build exclusively on x86_64, as kernel module idxd.ko cannot be
  found on i586
* Thu Dec 30 2021 danilo.spinella@suse.com
- Update to version 3.4.4:
  * Add -e/--enable and -f/--force features to load-config command
  * Add more sample configuration files for different usages
  * Add multi-descriptor support
- Update to version 3.4.3:
  * Remove redundant dependencies (kmod and udev)
  * Bug fixes and code cleanup
  * DSA test adds device and wq selection
  * DSA test adds no opcode operation support
* Fri Oct  8 2021 danilo.spinella@suse.com
- Update to version 3.4.2
  * Add feature to skip tests based on feature availability
  * Skip tests requiring shared memory if feature not available
  * Add API to retrieve wq occupancy attribute
* Thu Sep  9 2021 danilo.spinella@suse.com
- Update to version 3.4.1
  * Bug fixes related to traffic-class
  * Add per-wq ATS disable support
  * Add extended error status reporting
  * Created local copy of UAPI header file idxd.h from /usr/include
  * Update driver name changes
  * Rewrite unit test removing hardcoding and other enhancements
  * Bug fixes
- Run spec-cleaner
* Tue Jun 29 2021 rpm@fthiessen.de
- Update to version 3.2
  * Add support for new device bind paths retaining compatibility
    with older kernels
  * Add support for UACCE interface to access char devices
  * Fixed several issues in filtering, config and listing code
  * Support all 256 bits of op_cap
  * Fix incorrect return values
  * Made removing all mdevs more intuitive
* Mon Apr 26 2021 rpm@fthiessen.de
- Update to version 3.1
  * Improved error messages and return values
  * Fix incorrect error return value from tool
  * Allow -1 special value for wq->groupid and fix related error
    messages
  * Fix incorrect manpage text for config-wq
  * Remove reference to non-interface header in interface header
  * Remove non-interface header from packaging
  * Use portable data types and fix build issues in 32 bit targets
- Dropped upstream merged v3.0.1-use-portable-data-types.patch
* Fri Feb 12 2021 lpechacek@suse.com
- Update to v3.0.1 (jsc#SLE-13348)
  - Added IAX support
  - Added implementation and support for new mdev types
  - Removed uuid type mdevs
  - Introduced a new wq API to set max batch and transfer size
  - Added new GPL2 and LGPL-2.1 license files
  - Library license changed to LGPL-2.1
  - Fixed static code analysis bugs
- Enhanced Description
- Added dependency on the idxd kernel driver
- Restricted architecture to x86 - DSA is embedded
  into Intel CPUs
- Added patch: v3.0.1-use-portable-data-types.patch
* Tue Sep 22 2020 mcalabkova@suse.com
- Initial packaging of v2.8 (jsc#SLE-15021)
